pub struct ProveConfig { /* private fields */ }Expand description
Configuration to prove information to the verifier.
Implementations
Sourceimpl ProveConfig
impl ProveConfig
Sourcepub fn builder(transcript: &Transcript) -> ProveConfigBuilder<'_>
pub fn builder(transcript: &Transcript) -> ProveConfigBuilder<'_>
Creates a new builder.
Sourcepub fn server_identity(&self) -> bool
pub fn server_identity(&self) -> bool
Returns true if the server identity is to be proven.
Sourcepub fn reveal(&self) -> Option<&(RangeSet<usize>, RangeSet<usize>)>
pub fn reveal(&self) -> Option<&(RangeSet<usize>, RangeSet<usize>)>
Returns the sent and received ranges of the transcript to be revealed, respectively.
Sourcepub fn transcript_commit(&self) -> Option<&TranscriptCommitConfig>
pub fn transcript_commit(&self) -> Option<&TranscriptCommitConfig>
Returns the transcript commitment configuration.
Sourcepub fn to_request(&self) -> ProveRequest
pub fn to_request(&self) -> ProveRequest
Returns a request.